<?php

namespace common\models;

use Yii;

/**
 * This is the model class for table "{{%menu}}".
 *
 * @property string $id
 * @property int $type
 * @property string $parent_id
 * @property string $name
 * @property string $url
 * @property string $icon
 * @property string $sort
 * @property enum $target
 * @property enum is_absolute_url
 * @property string $is_display
 * @property string $created_at
 * @property string $updated_at
 */
class Menu extends \yii\db\ActiveRecord
{
    const BACKEND_TYPE = 0;
    const FRONTEND_TYPE = 1;

    const DISPLAY_YES = 1;
    const DISPLAY_NO = 0;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%menu}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['parent_id', 'sort'], 'integer'],
            [['is_display'], 'string'],
            [['name', 'url', 'icon', 'method'], 'string', 'max' => 255],
            [['type', 'is_absolute_url'] , 'in', 'range'=>[0, 1]],
            [['target'], 'in', 'range'=>[ '_blank', '_self']],
            [['name', 'url'], 'required'],
            [['method'], 'required', 'on'=>['backend']],
        ];
    }

    public function scenarios()
    {
        return [
            'backend' => ['parent_id', 'name', 'url', 'icon', 'type', 'is_absolute_url', 'target', 'sort', 'is_display', 'method'],
            'frontend' => ['parent_id', 'name', 'url', 'icon', 'type', 'is_absolute_url', 'target', 'sort', 'is_display'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'type' => Yii::t('app', 'Type'),
            'parent_id' => Yii::t('app', 'Parent Id'),
            'name' => Yii::t('app', 'Name'),
            'url' => Yii::t('app', 'Url'),
            'method' => Yii::t('app', 'HTTP Method'),
            'icon' => Yii::t('app', 'Icon'),
            'sort' => Yii::t('app', 'Sort'),
            'is_absolute_url' => Yii::t('app', 'Is Absolute Url'),
            'target' => Yii::t('app', 'Target'),
            'is_display' => Yii::t('app', 'Is Display'),
            'created_at' => Yii::t('app', 'Created At'),
            'updated_at' => Yii::t('app', 'Updated At'),
        ];
    }

    public function beforeSave($insert)
    {
        if($insert){
            $this->created_at = time();
        }else{
            $this->updated_at = time();
        }
        return true; // TODO: Change the autogenerated stub
    }

    public static function getMenuArray($type)
    {
        $model = new self();
        $menus = $model->find()->where(['type'=>$type])->orderBy("sort asc,parent_id asc")->asArray()->all();//var_dump($menus);die;
        $data = [];
        foreach ($menus as $key => $menu) {
            if ($menu['parent_id'] != 0) continue;
            $menu['level'] = 0;
            $menu['name'] = $menu['name'];
            $data[$menu['id']] = $menu;
            unset($menus[$key]);
            $temp = self::_getSubMenuArray($menus, $menu['id'], 1);
            if(is_array($temp)) {
                foreach ($temp as $v) {
                    if (!is_array($v)) continue;
                    $data[$v['id']] = $v;
                }
            }
        }
        return $data;
    }
    private static function _getSubMenuArray($menus, $cur_id, $level){
        $return = '';
        foreach($menus as $key => $menu){
            if($menu['parent_id'] != $cur_id) continue;
            $menu['level'] = $level;
            $menu['name'] = $menu['name'];
            $return[] = $menu;
            unset($menus[$key]);
            $subMenu = self::_getSubMenuArray($menus, $menu['id'], $level+1);
            if(is_array($subMenu)) {
                foreach ($subMenu as $val) {
                    if (!is_array($val)) continue;
                    $return[] = $val;
                }
            }
        }
        return $return;
    }

    public static function getParentMenu($type)
    {
        $menus = self::getMenuArray($type);
        $newMenu = [];//var_dump($menus);die;
        while(list($key, $val) = each($menus)){
            $newMenu[$val['id']] = str_repeat("---", $val['level']).$val['name'];
        }
        return $newMenu;
    }
}
